lxm3.xm\_cluster.PythonPackage
==============================

.. currentmodule:: lxm3.xm_cluster

.. autoclass:: PythonPackage

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~PythonPackage.__init__
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~PythonPackage.name
      ~PythonPackage.entrypoint
      ~PythonPackage.path
      ~PythonPackage.resources
      ~PythonPackage.extra_packages
      ~PythonPackage.pip_args
   
   